;+
;NAME:
;	dtcf_ph_hxs
;PURPOSE:        
;       Deadtime correction factor for HXS-PH. The correction is not exact
;       when the deadtime-corrected count of total PH exceeds about 35,000
;       counts/sec. In addition, spectral distorsion occurs when the deadtime-
;       corrected count of total PH exceeds about 21,000 counts/sec. It is due
;       to instrument limitation.
;CALLING SEQUENCE:
;	subs = dtcf_ph_hxs(float)
;INPUTS:
;	float - ( HXS-PH(SUM( 0-31ch.) ) [counts/sec]
;HISTORY:
;	26-Jun-93  (K.Suga) First written.
;       25-nov-93  Revised by J.Sato,K.Morimoto and M.Yoshimori
;-
;        << HXS-PC1, HXS-PC2 dead time = 7.83 micro sec.>>
;
function dtcf_ph_hxs,ht

ht = float( ht )

if ( ht lt 8400.) then begin

   dtcf = 1.0059 - 5.2422e-5*ht +7.2780e-8*ht^2 $
          - 1.4251e-11*ht^3 + 1.0407e-15*ht^4 + 9.9369e-21*ht^5

endif else begin

   dtcf = 2.2276 + 7.0923e-4*(ht-7480.) - 1.0177e-6*(ht-7480.)^2 $
        + 1.6301e-9*(ht-7480.)^3 - 7.6686e-13*(ht-7480.)^4 + 1.6471e-16*(ht-7480.)^5

endelse

return,dtcf
end

